'' =================================================================================================
''
''   File....... jm_led_toggle.spin
''   Purpose....
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (C) 2018 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started....
''   Updated.... 20 JAN 2018
''
'' =================================================================================================


con { timing }

  _clkmode = xtal1 + pll16x                                     
  _xinfreq = 5_000_000                                          ' use 5MHz crystal

  CLK_FREQ = (_clkmode >> 6) * _xinfreq                         ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                   ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                               ' ticks in 1us

  TRM_BAUD = 115_200                                            ' terminal baud rate
  

con { PAB io pins }                                                  
                                                                 
  RX1   = 31  { I }                                             ' serial / programming
  TX1   = 30  { O }                                            
                                                               
  SDA1  = 29  { I/O }                                           ' i2c / eeprom
  SCL1  = 28  { I/O }

  LED27 = 27  { O }
  LED26 = 26  { O }



obj

' main                                                          ' * master Spin cog
  time : "jm_time"                                              '   timing and delays
  io   : "jm_io_basic"                                          '   essential io
  term : "jm_fullduplexserial"                                  ' * serial IO for terminal
                                                                 
' * uses cog when loaded                                         
                                                                 
                                                                 
var                                                              
                                                                 
                                                                 
pub main | c                                                        
                                                                 
  setup                                                          
                                                                 
  repeat
    c := term.rx                                                ' wait for command
    case c
      "A" :
        io.toggle(LED26)                                        ' toggle LED
        if (ina[LED26])                                         ' report current state
          term.tx("A")
        else
          term.tx("a")

      "B" :
        io.toggle(LED27)
        if (ina[LED27])
          term.tx("B")
        else
          term.tx("b") 
                                             
                                                                 
                                                                 
pub setup                                                        
                                                                 
'' Setup IO and objects for application                          
                                                                 
  time.start                                                    ' setup timing & delays

  io.start(0, 0)                                                ' clear all pins (master cog)
                                                                 
  term.start(RX1, TX1, %0000, TRM_BAUD)                         ' start serial for terminal
                                                                 
              
dat { license }

{{

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 

}}      